# CONTAINER FLAGS
CONTAINER_APP = 0x1000000000000000
CONTAINER_VIEW = 0x2000000000000000

# COMPONENT FLAGS
COMPONENT_TEXT = 0x0000000000000001
COMPONENT_TEXT_AREA = 0x0000000000000002

COMPONENT_INT = 0x0000000000000010
COMPONENT_INT_SLIDER = 0x0000000000000020

COMPONENT_FLOAT = 0x0000000000000100
COMPONENT_FLOAT_SLIDER = 0x0000000000000200
